@@ -1,4 +1,3 @@
-
 from docutils.core import publish_parts
 
 from django.conf import settings
@@ -14,21 +13,24 @@ CONTENT_FORMAT_CHOICES = (
     (PLAIN_TEXT, u"Plain Text"),
 )
 
-DOCUTILS_SETTINGS = getattr(settings, 'DOCUTILS_SETTINGS',
-    {  'doctitle_xform': False,
-       'initial_header_level': 4,
-       'id_prefix': 's-',
-    }
-)
+DOCUTILS_SETTINGS = getattr(settings, 'DOCUTILS_SETTINGS', {
+    'doctitle_xform': False,
+    'initial_header_level': 4,
+    'id_prefix': 's-',
+})
+
 
 def reST_to_html(text):
-    return publish_parts(source=smart_str(text),
-                         writer_name="html",
-                         settings_overrides=DOCUTILS_SETTINGS)['fragment']
+    return publish_parts(
+        source=smart_str(text),
+        writer_name="html",
+        settings_overrides=DOCUTILS_SETTINGS)['fragment']
+
 
 def text_to_html(text):
     return linebreaksbr(text)
 
+
 def convert_to_html(text, content_type):
     if content_type == PLAIN_TEXT:
         html = text_to_html(text)
