@@ -1,8 +1,8 @@
-
 from django.core.exceptions import ValidationError
-from django.core.urlresolvers import resolve
+from django.urls import resolve
 from django.http import Http404
 
+
 def internal_path_exists(path):
     """
     Validates that url path is registered and can properly be resolved
